/********************************************************************************
** Form generated from reading UI file 'basicsettings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BASICSETTINGS_H
#define UI_BASICSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_BasicSettings
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QRadioButton *bottomRightRB;
    QRadioButton *centerRightRB;
    QRadioButton *centerCenterRB;
    QSpacerItem *horizontalSpacer;
    QRadioButton *topCenterRB;
    QRadioButton *bottomCenterRB;
    QRadioButton *topLeftRB;
    QRadioButton *topRightRB;
    QRadioButton *centerLeftRB;
    QRadioButton *bottomLeftRB;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer;
    QLabel *warningLabel;
    QButtonGroup *buttonGroup;

    void setupUi(QWidget *BasicSettings)
    {
        if (BasicSettings->objectName().isEmpty())
            BasicSettings->setObjectName(QStringLiteral("BasicSettings"));
        BasicSettings->resize(148, 179);
        verticalLayout = new QVBoxLayout(BasicSettings);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        label = new QLabel(BasicSettings);
        label->setObjectName(QStringLiteral("label"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label->setFont(font);

        verticalLayout->addWidget(label);

        groupBox = new QGroupBox(BasicSettings);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        groupBox->setAlignment(Qt::AlignCenter);
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        bottomRightRB = new QRadioButton(groupBox);
        buttonGroup = new QButtonGroup(BasicSettings);
        buttonGroup->setObjectName(QStringLiteral("buttonGroup"));
        buttonGroup->addButton(bottomRightRB);
        bottomRightRB->setObjectName(QStringLiteral("bottomRightRB"));
        bottomRightRB->setChecked(true);

        gridLayout->addWidget(bottomRightRB, 2, 4, 1, 1);

        centerRightRB = new QRadioButton(groupBox);
        buttonGroup->addButton(centerRightRB);
        centerRightRB->setObjectName(QStringLiteral("centerRightRB"));

        gridLayout->addWidget(centerRightRB, 1, 4, 1, 1);

        centerCenterRB = new QRadioButton(groupBox);
        buttonGroup->addButton(centerCenterRB);
        centerCenterRB->setObjectName(QStringLiteral("centerCenterRB"));

        gridLayout->addWidget(centerCenterRB, 1, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 1, 1, 1);

        topCenterRB = new QRadioButton(groupBox);
        buttonGroup->addButton(topCenterRB);
        topCenterRB->setObjectName(QStringLiteral("topCenterRB"));

        gridLayout->addWidget(topCenterRB, 0, 2, 1, 1);

        bottomCenterRB = new QRadioButton(groupBox);
        buttonGroup->addButton(bottomCenterRB);
        bottomCenterRB->setObjectName(QStringLiteral("bottomCenterRB"));

        gridLayout->addWidget(bottomCenterRB, 2, 2, 1, 1);

        topLeftRB = new QRadioButton(groupBox);
        buttonGroup->addButton(topLeftRB);
        topLeftRB->setObjectName(QStringLiteral("topLeftRB"));

        gridLayout->addWidget(topLeftRB, 0, 0, 1, 1);

        topRightRB = new QRadioButton(groupBox);
        buttonGroup->addButton(topRightRB);
        topRightRB->setObjectName(QStringLiteral("topRightRB"));

        gridLayout->addWidget(topRightRB, 0, 4, 1, 1);

        centerLeftRB = new QRadioButton(groupBox);
        buttonGroup->addButton(centerLeftRB);
        centerLeftRB->setObjectName(QStringLiteral("centerLeftRB"));

        gridLayout->addWidget(centerLeftRB, 1, 0, 1, 1);

        bottomLeftRB = new QRadioButton(groupBox);
        buttonGroup->addButton(bottomLeftRB);
        bottomLeftRB->setObjectName(QStringLiteral("bottomLeftRB"));

        gridLayout->addWidget(bottomLeftRB, 2, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 3, 1, 1);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(105, 51, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        warningLabel = new QLabel(BasicSettings);
        warningLabel->setObjectName(QStringLiteral("warningLabel"));
        warningLabel->setWordWrap(true);

        verticalLayout->addWidget(warningLabel);


        retranslateUi(BasicSettings);

        QMetaObject::connectSlotsByName(BasicSettings);
    } // setupUi

    void retranslateUi(QWidget *BasicSettings)
    {
        label->setText(QApplication::translate("BasicSettings", "Basic Settings", 0));
        groupBox->setTitle(QApplication::translate("BasicSettings", "Position on screen", 0));
        bottomRightRB->setText(QString());
        centerRightRB->setText(QString());
        centerCenterRB->setText(QString());
        topCenterRB->setText(QString());
        bottomCenterRB->setText(QString());
        topLeftRB->setText(QString());
        topRightRB->setText(QString());
        centerLeftRB->setText(QString());
        bottomLeftRB->setText(QString());
        Q_UNUSED(BasicSettings);
    } // retranslateUi

};

namespace Ui {
    class BasicSettings: public Ui_BasicSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_BASICSETTINGS_H
