/********************************************************************************
** Form generated from reading UI file 'advancedsettings.ui'
**
** Created by: Qt User Interface Compiler version 5.6.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADVANCEDSETTINGS_H
#define UI_ADVANCEDSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AdvancedSettings
{
public:
    QGridLayout *gridLayout_2;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_4;
    QLabel *spacingLabel;
    QSpinBox *widthBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *widthLabel;
    QSpinBox *spacingBox;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QLabel *serverDecidesLabel;
    QSpinBox *serverDecidesBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *AdvancedSettings)
    {
        if (AdvancedSettings->objectName().isEmpty())
            AdvancedSettings->setObjectName(QStringLiteral("AdvancedSettings"));
        AdvancedSettings->resize(350, 301);
        gridLayout_2 = new QGridLayout(AdvancedSettings);
        gridLayout_2->setObjectName(QStringLiteral("gridLayout_2"));
        groupBox = new QGroupBox(AdvancedSettings);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QStringLiteral("horizontalLayout_4"));
        spacingLabel = new QLabel(groupBox);
        spacingLabel->setObjectName(QStringLiteral("spacingLabel"));

        horizontalLayout_4->addWidget(spacingLabel);

        widthBox = new QSpinBox(groupBox);
        widthBox->setObjectName(QStringLiteral("widthBox"));
        widthBox->setMinimum(10);
        widthBox->setMaximum(2000);

        horizontalLayout_4->addWidget(widthBox);


        verticalLayout->addLayout(horizontalLayout_4);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName(QStringLiteral("horizontalLayout_3"));
        widthLabel = new QLabel(groupBox);
        widthLabel->setObjectName(QStringLiteral("widthLabel"));

        horizontalLayout_3->addWidget(widthLabel);

        spacingBox = new QSpinBox(groupBox);
        spacingBox->setObjectName(QStringLiteral("spacingBox"));

        horizontalLayout_3->addWidget(spacingBox);


        verticalLayout->addLayout(horizontalLayout_3);


        gridLayout_2->addWidget(groupBox, 1, 0, 2, 2);

        groupBox_2 = new QGroupBox(AdvancedSettings);
        groupBox_2->setObjectName(QStringLiteral("groupBox_2"));
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName(QStringLiteral("label_3"));
        QSizePolicy sizePolicy(QSizePolicy::Preferred, QSizePolicy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);
        label_3->setWordWrap(true);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        serverDecidesLabel = new QLabel(groupBox_2);
        serverDecidesLabel->setObjectName(QStringLiteral("serverDecidesLabel"));

        horizontalLayout->addWidget(serverDecidesLabel);

        serverDecidesBox = new QSpinBox(groupBox_2);
        serverDecidesBox->setObjectName(QStringLiteral("serverDecidesBox"));
        serverDecidesBox->setMaximum(7200);

        horizontalLayout->addWidget(serverDecidesBox);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);


        gridLayout_2->addWidget(groupBox_2, 0, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 2);


        retranslateUi(AdvancedSettings);

        QMetaObject::connectSlotsByName(AdvancedSettings);
    } // setupUi

    void retranslateUi(QWidget *AdvancedSettings)
    {
        groupBox->setTitle(QApplication::translate("AdvancedSettings", "Sizes", 0));
        spacingLabel->setText(QApplication::translate("AdvancedSettings", "Width:", 0));
        widthBox->setSuffix(QApplication::translate("AdvancedSettings", " px", 0));
        widthLabel->setText(QApplication::translate("AdvancedSettings", "Spacing:", 0));
        spacingBox->setSuffix(QApplication::translate("AdvancedSettings", " px", 0));
        groupBox_2->setTitle(QApplication::translate("AdvancedSettings", "Duration", 0));
        label_3->setText(QApplication::translate("AdvancedSettings", "Some notifications set their own on-screen duration.", 0));
        serverDecidesLabel->setText(QApplication::translate("AdvancedSettings", "Default duration:", 0));
        serverDecidesBox->setSuffix(QApplication::translate("AdvancedSettings", " sec", 0));
        Q_UNUSED(AdvancedSettings);
    } // retranslateUi

};

namespace Ui {
    class AdvancedSettings: public Ui_AdvancedSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ADVANCEDSETTINGS_H
