/****************************************************************************
** Meta object code from reading C++ file 'notificationwidgets.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-notificationd-0.11.0/src/notificationwidgets.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationwidgets.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_NotificationActionsWidget_t {
    QByteArrayData data[4];
    char stringdata0[53];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NotificationActionsWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NotificationActionsWidget_t qt_meta_stringdata_NotificationActionsWidget = {
    {
QT_MOC_LITERAL(0, 0, 25), // "NotificationActionsWidget"
QT_MOC_LITERAL(1, 26, 15), // "actionTriggered"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 9) // "actionKey"

    },
    "NotificationActionsWidget\0actionTriggered\0"
    "\0actionKey"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NotificationActionsWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void NotificationActionsWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotificationActionsWidget *_t = static_cast<NotificationActionsWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionTriggered((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (NotificationActionsWidget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationActionsWidget::actionTriggered)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject NotificationActionsWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_NotificationActionsWidget.data,
      qt_meta_data_NotificationActionsWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *NotificationActionsWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationActionsWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_NotificationActionsWidget.stringdata0))
        return static_cast<void*>(const_cast< NotificationActionsWidget*>(this));
    return QWidget::qt_metacast(_clname);
}

int NotificationActionsWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void NotificationActionsWidget::actionTriggered(const QString & _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_NotificationActionsButtonsWidget_t {
    QByteArrayData data[5];
    char stringdata0[80];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NotificationActionsButtonsWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NotificationActionsButtonsWidget_t qt_meta_stringdata_NotificationActionsButtonsWidget = {
    {
QT_MOC_LITERAL(0, 0, 32), // "NotificationActionsButtonsWidget"
QT_MOC_LITERAL(1, 33, 21), // "actionButtonActivated"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 16), // "QAbstractButton*"
QT_MOC_LITERAL(4, 73, 6) // "button"

    },
    "NotificationActionsButtonsWidget\0"
    "actionButtonActivated\0\0QAbstractButton*\0"
    "button"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NotificationActionsButtonsWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void NotificationActionsButtonsWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotificationActionsButtonsWidget *_t = static_cast<NotificationActionsButtonsWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionButtonActivated((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractButton* >(); break;
            }
            break;
        }
    }
}

const QMetaObject NotificationActionsButtonsWidget::staticMetaObject = {
    { &NotificationActionsWidget::staticMetaObject, qt_meta_stringdata_NotificationActionsButtonsWidget.data,
      qt_meta_data_NotificationActionsButtonsWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *NotificationActionsButtonsWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationActionsButtonsWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_NotificationActionsButtonsWidget.stringdata0))
        return static_cast<void*>(const_cast< NotificationActionsButtonsWidget*>(this));
    return NotificationActionsWidget::qt_metacast(_clname);
}

int NotificationActionsButtonsWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationActionsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_NotificationActionsComboWidget_t {
    QByteArrayData data[3];
    char stringdata0[56];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NotificationActionsComboWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NotificationActionsComboWidget_t qt_meta_stringdata_NotificationActionsComboWidget = {
    {
QT_MOC_LITERAL(0, 0, 30), // "NotificationActionsComboWidget"
QT_MOC_LITERAL(1, 31, 23), // "actionComboBoxActivated"
QT_MOC_LITERAL(2, 55, 0) // ""

    },
    "NotificationActionsComboWidget\0"
    "actionComboBoxActivated\0"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NotificationActionsComboWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void NotificationActionsComboWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotificationActionsComboWidget *_t = static_cast<NotificationActionsComboWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->actionComboBoxActivated(); break;
        default: ;
        }
    }
    Q_UNUSED(_a);
}

const QMetaObject NotificationActionsComboWidget::staticMetaObject = {
    { &NotificationActionsWidget::staticMetaObject, qt_meta_stringdata_NotificationActionsComboWidget.data,
      qt_meta_data_NotificationActionsComboWidget,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *NotificationActionsComboWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationActionsComboWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_NotificationActionsComboWidget.stringdata0))
        return static_cast<void*>(const_cast< NotificationActionsComboWidget*>(this));
    return NotificationActionsWidget::qt_metacast(_clname);
}

int NotificationActionsComboWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = NotificationActionsWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
