/****************************************************************************
** Meta object code from reading C++ file 'notificationlayout.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.6.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/lxqt-notificationd-0.11.0/src/notificationlayout.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationlayout.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.6.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
struct qt_meta_stringdata_NotificationLayout_t {
    QByteArrayData data[22];
    char stringdata0[293];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_NotificationLayout_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_NotificationLayout_t qt_meta_stringdata_NotificationLayout = {
    {
QT_MOC_LITERAL(0, 0, 18), // "NotificationLayout"
QT_MOC_LITERAL(1, 19, 22), // "allNotificationsClosed"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 21), // "notificationAvailable"
QT_MOC_LITERAL(4, 65, 13), // "heightChanged"
QT_MOC_LITERAL(5, 79, 18), // "notificationClosed"
QT_MOC_LITERAL(6, 98, 2), // "id"
QT_MOC_LITERAL(7, 101, 6), // "reason"
QT_MOC_LITERAL(8, 108, 13), // "actionInvoked"
QT_MOC_LITERAL(9, 122, 9), // "actionKey"
QT_MOC_LITERAL(10, 132, 15), // "addNotification"
QT_MOC_LITERAL(11, 148, 11), // "application"
QT_MOC_LITERAL(12, 160, 7), // "summary"
QT_MOC_LITERAL(13, 168, 4), // "body"
QT_MOC_LITERAL(14, 173, 4), // "icon"
QT_MOC_LITERAL(15, 178, 7), // "timeout"
QT_MOC_LITERAL(16, 186, 7), // "actions"
QT_MOC_LITERAL(17, 194, 5), // "hints"
QT_MOC_LITERAL(18, 200, 18), // "removeNotification"
QT_MOC_LITERAL(19, 219, 25), // "removeNotificationTimeout"
QT_MOC_LITERAL(20, 245, 22), // "removeNotificationUser"
QT_MOC_LITERAL(21, 268, 24) // "notificationActionCalled"

    },
    "NotificationLayout\0allNotificationsClosed\0"
    "\0notificationAvailable\0heightChanged\0"
    "notificationClosed\0id\0reason\0actionInvoked\0"
    "actionKey\0addNotification\0application\0"
    "summary\0body\0icon\0timeout\0actions\0"
    "hints\0removeNotification\0"
    "removeNotificationTimeout\0"
    "removeNotificationUser\0notificationActionCalled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_NotificationLayout[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   64,    2, 0x06 /* Public */,
       3,    0,   65,    2, 0x06 /* Public */,
       4,    1,   66,    2, 0x06 /* Public */,
       5,    2,   69,    2, 0x06 /* Public */,
       8,    2,   74,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      10,    8,   79,    2, 0x0a /* Public */,
      18,    2,   96,    2, 0x0a /* Public */,
      19,    0,  101,    2, 0x08 /* Private */,
      20,    0,  102,    2, 0x08 /* Private */,
      21,    1,  103,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,    6,    7,
    QMetaType::Void, QMetaType::UInt, QMetaType::QString,    6,    9,

 // slots: parameters
    QMetaType::Void, QMetaType::UInt, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::Int, QMetaType::QStringList, QMetaType::QVariantMap,    6,   11,   12,   13,   14,   15,   16,   17,
    QMetaType::Void, QMetaType::UInt, QMetaType::UInt,    6,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    9,

       0        // eod
};

void NotificationLayout::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        NotificationLayout *_t = static_cast<NotificationLayout *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->allNotificationsClosed(); break;
        case 1: _t->notificationAvailable(); break;
        case 2: _t->heightChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->notificationClosed((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 4: _t->actionInvoked((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->addNotification((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< int(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QVariantMap(*)>(_a[8]))); break;
        case 6: _t->removeNotification((*reinterpret_cast< uint(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2]))); break;
        case 7: _t->removeNotificationTimeout(); break;
        case 8: _t->removeNotificationUser(); break;
        case 9: _t->notificationActionCalled((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (NotificationLayout::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationLayout::allNotificationsClosed)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (NotificationLayout::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationLayout::notificationAvailable)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (NotificationLayout::*_t)(int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationLayout::heightChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (NotificationLayout::*_t)(uint , uint );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationLayout::notificationClosed)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (NotificationLayout::*_t)(uint , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&NotificationLayout::actionInvoked)) {
                *result = 4;
                return;
            }
        }
    }
}

const QMetaObject NotificationLayout::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_NotificationLayout.data,
      qt_meta_data_NotificationLayout,  qt_static_metacall, Q_NULLPTR, Q_NULLPTR}
};


const QMetaObject *NotificationLayout::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotificationLayout::qt_metacast(const char *_clname)
{
    if (!_clname) return Q_NULLPTR;
    if (!strcmp(_clname, qt_meta_stringdata_NotificationLayout.stringdata0))
        return static_cast<void*>(const_cast< NotificationLayout*>(this));
    return QWidget::qt_metacast(_clname);
}

int NotificationLayout::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void NotificationLayout::allNotificationsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, Q_NULLPTR);
}

// SIGNAL 1
void NotificationLayout::notificationAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 1, Q_NULLPTR);
}

// SIGNAL 2
void NotificationLayout::heightChanged(int _t1)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void NotificationLayout::notificationClosed(uint _t1, uint _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void NotificationLayout::actionInvoked(uint _t1, const QString & _t2)
{
    void *_a[] = { Q_NULLPTR, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_END_MOC_NAMESPACE
